Simultaneous model fitting
=============================

The class *SyncFitContainer* is designed to provide a simple interface for fitting
different models defined on different axes simultaneously. It is designed to
mimic the behavior of the *OneDFit* class, but is not itself an object
derived from *OneDFit*. An example of usage is given in the tutorial.  

.. currentmodule:: PyAstronomy.funcFit
.. autoclass::  SyncFitContainer
   :members: